sqlmesh.core.config.categorizer API documentation

Edit on GitHub

# sqlmesh.core.config.categorizer

View Source

     1from __future__ import annotations
     2
     3from enum import Enum
     4
     5from sqlmesh.core.config.base import BaseConfig
     6
     7
     8class AutoCategorizationMode(Enum):
     9    FULL = "full"
    10    """Full-auto mode in which the categorizer falls back to the most conservative choice (breaking)."""
    11
    12    SEMI = "semi"
    13    """Semi-auto mode in which a user is promted to provide a category in case when the categorizer
    14    failed to determine it automatically.
    15    """
    16
    17    OFF = "off"
    18    """Disables automatic categorization."""
    19
    20
    21class CategorizerConfig(BaseConfig):
    22    """Configuration for the automatic categorizer of snapshot changes.
    23
    24    Args:
    25        python: the auto categorization mode for Python models.
    26        sql: the auto categorization mode for SQL models.
    27        seed: the auto categorization mode for Seed models.
    28    """
    29
    30    python: AutoCategorizationMode = AutoCategorizationMode.OFF
    31    sql: AutoCategorizationMode = AutoCategorizationMode.FULL
    32    seed: AutoCategorizationMode = AutoCategorizationMode.FULL

class AutoCategorizationMode(enum.Enum): View Source

     9class AutoCategorizationMode(Enum):
    10    FULL = "full"
    11    """Full-auto mode in which the categorizer falls back to the most conservative choice (breaking)."""
    12
    13    SEMI = "semi"
    14    """Semi-auto mode in which a user is promted to provide a category in case when the categorizer
    15    failed to determine it automatically.
    16    """
    17
    18    OFF = "off"
    19    """Disables automatic categorization."""

An enumeration.

FULL = <AutoCategorizationMode.FULL: 'full'>

Full-auto mode in which the categorizer falls back to the most conservative choice (breaking).

SEMI = <AutoCategorizationMode.SEMI: 'semi'>

Semi-auto mode in which a user is promted to provide a category in case when the categorizer failed to determine it automatically.

OFF = <AutoCategorizationMode.OFF: 'off'>

Disables automatic categorization.

##### Inherited Members

enum.Enum
  name
  value

class CategorizerConfig(sqlmesh.core.config.base.BaseConfig): View Source

    22class CategorizerConfig(BaseConfig):
    23    """Configuration for the automatic categorizer of snapshot changes.
    24
    25    Args:
    26        python: the auto categorization mode for Python models.
    27        sql: the auto categorization mode for SQL models.
    28        seed: the auto categorization mode for Seed models.
    29    """
    30
    31    python: AutoCategorizationMode = AutoCategorizationMode.OFF
    32    sql: AutoCategorizationMode = AutoCategorizationMode.FULL
    33    seed: AutoCategorizationMode = AutoCategorizationMode.FULL

Configuration for the automatic categorizer of snapshot changes.

###### Arguments:

- python: the auto categorization mode for Python models.
- sql: the auto categorization mode for SQL models.
- seed: the auto categorization mode for Seed models.

##### Inherited Members

pydantic.main.BaseModel
  BaseModel
  parse_obj
  parse_raw
  parse_file
  from_orm
  construct
  copy
  schema
  schema_json
  validate
  update_forward_refs
sqlmesh.core.config.base.BaseConfig
  update_with
sqlmesh.utils.pydantic.PydanticModel
  Config
  dict
  json
  missing_required_fields
  extra_fields
  all_fields
  required_fields